<?php

declare(strict_types=1);

namespace Drupal\oktaplus\Enum;

/**
 * Action to take when receiving user add events.
 */
enum UserAddAction: string {

  // Ignore the event.
  case Ignore = 'ignore';

  // Create a user from the event.
  case Create = 'create';

  // Create and activate a user from the event.
  case Activate = 'activate';

  /**
   * Get a label for use in forms.
   */
  public function label(): string {
    return match ($this) {
      self::Ignore => 'No action',
      self::Create => 'Create user in blocked state',
      self::Activate => 'Create user in activated state',
    };
  }

  /**
   * Get a past-tense value.
   */
  public function pastTense(): string {
    return match ($this) {
      self::Ignore => 'ignored',
      self::Create => 'created',
      self::Activate => 'activated',
    };
  }

  /**
   * Get form options.
   */
  public static function asOptions(): array {
    $options = [];
    foreach (self::cases() as $case) {
      $options[$case->value] = $case->label();
    }
    return $options;
  }

}
