<?php

declare(strict_types=1);

namespace Drupal\oktaplus\Routing;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\oktaplus\Controller\EventHookController;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

final class OktaplusRouteSubscriber extends RouteSubscriberBase {

  public function __construct(
    protected ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection): void {
    $config = $this->configFactory->get('oktaplus.settings');
    $path = $config->get('event_hook_path');
    if ($path === NULL) {
      return;
    }

    $collection->add('oktaplus.event_hook.verification', (new Route($path))
      ->addDefaults([
        '_controller' => EventHookController::class . '::handleVerification',
      ])
      ->setMethods(['GET'])
      ->setRequirement('_access', 'TRUE'),
    );

    $collection->add('oktaplus.event_hook.event', (new Route($path))
      ->addDefaults([
        '_controller' => EventHookController::class . '::handleEvent',
      ])
      ->setMethods(['POST'])
      ->setRequirement('_access', 'TRUE')
      ->setRequirement('_content_type_format', 'json'),
    );
  }

}
